@@ -1,4 +1,4 @@
-from typing import Any, Callable, Dict, Iterator, Optional, Type, Tuple, Union
+from typing import Any, Callable, Dict, Iterator, Type, Tuple
 import ipywidgets as widgets
 import traitlets
 
@@ -9,7 +9,7 @@ FilterType = Callable[
 
 VariantIterator = Iterator[Tuple[Type[widgets.Widget], Dict[str, Any]]]
 TraitViewFactoryType = Callable[
-    [traitlets.TraitType, Dict[str, Any], "ViewFactoryContext"], VariantIterator
+    [traitlets.TraitType, "ViewFactoryContext"], VariantIterator
 ]
 _trait_view_variant_factories: Dict[
     Type[traitlets.TraitType], TraitViewFactoryType
